@@ -1,5 +1,6 @@
-## ----setup, echo = 1-----------------------------------------------------
+## ----setup, echo = c(1, 2)-----------------------------------------------
 library(reda)
+packageVersion("reda")
 knitr::opts_chunk$set(fig.height = 5, fig.width = 7)
 
 ## ----data----------------------------------------------------------------
@@ -8,11 +9,11 @@ str(simuDat)
 
 ## ----sampleMcf-----------------------------------------------------------
 ## Example 1. valve-seat data
-valveMcf0 <- mcf(Survr(ID, Days, No.) ~ 1, data = valveSeats)
+valveMcf0 <- mcf(Recur(Days, ID, No.) ~ 1, data = valveSeats)
 
 ## Example 2. the simulated data
-simuMcf <- mcf(Survr(ID, time, event) ~ group + gender,
-               data = simuDat, subset = ID %in% 1 : 50)
+simuMcf <- mcf(Recur(time, ID, event) ~ group + gender,
+               data = simuDat, subset = ID %in% seq_len(50))
 
 ## ----plot:sampleMcf------------------------------------------------------
 ## overall sample MCF for valve-seat data in Nelson (1995)
@@ -20,15 +21,15 @@ plot(valveMcf0, conf.int = TRUE, mark.time = TRUE, addOrigin = TRUE, col = 2) +
     ggplot2::xlab("Days") + ggplot2::theme_bw()
 
 ## sample MCF for different groups (the default theme)
-plot(simuMcf, conf.int = TRUE, lty = 1 : 4, legendName = "Treatment & Gender")
+plot(simuMcf, conf.int = TRUE, lty = 1:4, legendName = "Treatment & Gender")
 
 ## ----plot:mcfSE----------------------------------------------------------
 ## Poisson process method
-valveMcf1 <- mcf(Survr(ID, Days, No.) ~ 1, valveSeats, variance = "Poisson")
+valveMcf1 <- mcf(Recur(Days, ID, No.) ~ 1, valveSeats, variance = "Poisson")
 
 ## bootstrap method (with 1,000 bootstrap samples)
 set.seed(123)
-valveMcf2 <- mcf(Survr(ID, Days, No.) ~ 1, valveSeats,
+valveMcf2 <- mcf(Recur(Days, ID, No.) ~ 1, valveSeats,
                  variance = "bootstrap", control = list(B = 1e3))
 
 ## comparing the standard error estimates
@@ -50,36 +51,36 @@ ggplot(ciDat, aes(x = time)) +
 
 ## ----mcfDiff1------------------------------------------------------------
 ## one sample MCF object of two groups
-mcf0 <- mcf(Survr(ID, time, event) ~ group, data = simuDat)
+mcf0 <- mcf(Recur(time, ID, event) ~ group, data = simuDat)
 (mcf_diff0 <- mcfDiff(mcf0))
 
 ## ----mcfDiff2------------------------------------------------------------
 ## explicitly ask for the difference of two sample MCF
-mcf1 <- mcf(Survr(ID, time, event) ~ 1, simuDat, group %in% "Contr")
-mcf2 <- mcf(Survr(ID, time, event) ~ 1, simuDat, group %in% "Treat")
+mcf1 <- mcf(Recur(time, ID, event) ~ 1, simuDat, group %in% "Contr")
+mcf2 <- mcf(Recur(time, ID, event) ~ 1, simuDat, group %in% "Treat")
 mcf1 - mcf2
 
 ## ----plot:mcfDiff--------------------------------------------------------
 plot(mcf_diff0)
 
 ## ----const---------------------------------------------------------------
-(constFit <- rateReg(Survr(ID, time, event) ~ group + x1, data = simuDat))
+(constFit <- rateReg(Recur(time, ID, event) ~ group + x1, data = simuDat))
 
 ## ----twoPieces-----------------------------------------------------------
 # two pieces' constant rate function
-(twoPiecesFit <- rateReg(Survr(ID, time, event) ~ group + x1, df = 2,
+(twoPiecesFit <- rateReg(Recur(time, ID, event) ~ group + x1, df = 2,
                          data = simuDat, subset = ID %in% 1:50))
 
 ## ----sixPieces-----------------------------------------------------------
-(piecesFit <- rateReg(Survr(ID, time, event) ~ group + x1, data = simuDat,
+(piecesFit <- rateReg(Recur(time, ID, event) ~ group + x1, data = simuDat,
                       knots = seq(from = 28, to = 140, by = 28)))
 
 ## ----spline--------------------------------------------------------------
 ## internal knots are set as 33% and 67% quantiles of time variable
-(splineFit <- rateReg(Survr(ID, time, event) ~ group + x1, data = simuDat,
+(splineFit <- rateReg(Recur(time, ID, event) ~ group + x1, data = simuDat,
                       df = 6, degree = 3, spline = "mSplines"))
 ## or internal knots are expicitly specified
-(splineFit <- rateReg(Survr(ID, time, event) ~ group + x1, data = simuDat,
+(splineFit <- rateReg(Recur(time, ID, event) ~ group + x1, data = simuDat,
                       spline = "bSp", degree = 3L, knots = c(56, 112)))
 
 ## ----summary-------------------------------------------------------------
